@@ -3,10 +3,6 @@
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
 
-version_info = (
-    2,
-    4,
-    1
-)
+version_info = (2, 4, 2)
 
 __version__ = '.'.join(map(str, version_info))
